pub struct LockOptions {
pub timeout: Duration,
pub stale: Duration,
pub poll: Duration,
}Fields
timeout: Durationstale: DurationOnly for a lock directory with no readable owner record: how long before it counts as abandoned. Never applied to a lock whose owner is alive.
poll: DurationTrait Implementations
Sourceimpl Clone for LockOptions
impl Clone for LockOptions
Sourceimpl Debug for LockOptions
impl Debug for LockOptions